Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1026)

Unified Diff: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h

Issue 2684723003: Remove LauncherItemController::Launch, cleanup. (Closed)
Patch Set: Use AppLauncherId Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
index b40a511a4f6879dca776b8384260f003b8049906..5aa42d462636ab2950b29ea18e54a650d20e8e9b 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
@@ -16,6 +16,7 @@
#include "chrome/browser/ui/app_icon_loader.h"
#include "chrome/browser/ui/app_icon_loader_delegate.h"
#include "chrome/browser/ui/app_list/app_list_controller_delegate.h"
+#include "chrome/browser/ui/ash/app_launcher_id.h"
#include "chrome/browser/ui/ash/launcher/chrome_launcher_types.h"
#include "chrome/browser/ui/ash/launcher/settings_window_observer.h"
#include "mojo/public/cpp/bindings/associated_binding.h"
@@ -134,19 +135,12 @@ class ChromeLauncherController : public ash::mojom::ShelfObserver,
// Returns true if the specified item is for a platform app.
virtual bool IsPlatformApp(ash::ShelfID id) = 0;
// Opens a new instance of the application identified by |app_id|.
// Used by the app-list, and by pinned-app shelf items.
- void LaunchApp(const std::string& app_id,
+ void LaunchApp(ash::launcher::AppLauncherId id,
ash::LaunchSource source,
int event_flags);
- // As above but includes |launch_id|, an id that can be passed to an app when
- // launched in order to support multiple shelf items per app.
- void LaunchAppWithLaunchId(const std::string& app_id,
- const std::string& launch_id,
- ash::LaunchSource source,
- int event_flags);
-
// If |app_id| is running, reactivates the app's most recently active window,
// otherwise launches and activates the app.
// Used by the app-list, and by pinned-app shelf items.
@@ -134,19 +135,12 @@ class ChromeLauncherController : public ash::mojom::ShelfObserver,
// Returns true if the specified item is for a platform app.
virtual bool IsPlatformApp(ash::ShelfID id) = 0;
- // Opens a new instance of the application identified by |app_id|.
+ // Opens a new instance of the application identified by the AppLauncherId.
// Used by the app-list, and by pinned-app shelf items.

Powered by Google App Engine
This is Rietveld 408576698